==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/packageableelement/impl/SearchResultSetSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.packageableelement.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.elementpackaging.EP_PKGSet;
import io.ciera.tool.sql.ooaofooa.elementpackaging.impl.EP_PKGSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.ElementVisibilitySet;
import io.ciera.tool.sql.ooaofooa.packageableelement.SearchResultSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.SearchResultSetSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.ElementVisibilitySetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ElementTypeConstants;


public class SearchResultSetSetImpl extends InstanceSet<SearchResultSetSet,SearchResultSet> implements SearchResultSetSet {

    // attributes
    @Override
    public void setType( ElementTypeConstants m_Type ) throws XtumlException {
        for ( SearchResultSet searchresultset : this ) searchresultset.setType( m_Type );
    }
    @Override
    public void setPackage_ID( UniqueId ref_Package_ID ) throws XtumlException {
        for ( SearchResultSet searchresultset : this ) searchresultset.setPackage_ID( ref_Package_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( SearchResultSet searchresultset : this ) searchresultset.setName( m_Name );
    }


    // selections
    @Override
    public EP_PKGSet R8005_held_by_EP_PKG() throws XtumlException {
        EP_PKGSet ep_pkgset = new EP_PKGSetImpl();
        for ( SearchResultSet searchresultset : this ) ep_pkgset.add( searchresultset.R8005_held_by_EP_PKG() );
        return ep_pkgset;
    }
    @Override
    public ElementVisibilitySet R8006_ElementVisibility() throws XtumlException {
        ElementVisibilitySet elementvisibilityset = new ElementVisibilitySetImpl();
        for ( SearchResultSet searchresultset : this ) elementvisibilityset.addAll( searchresultset.R8006_ElementVisibility() );
        return elementvisibilityset;
    }


    @Override
    public SearchResultSet nullElement() {
        return SearchResultSetImpl.EMPTY_SEARCHRESULTSET;
    }

    @Override
    public SearchResultSetSet emptySet() {
      return new SearchResultSetSetImpl();
    }

    @Override
    public SearchResultSetSet value() {
        return this;
    }

    @Override
    public List<SearchResultSet> elements() {
        SearchResultSet[] elements = toArray(new SearchResultSet[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/packageableelement/impl/SearchResultSetSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.packageableelement.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.elementpackaging.EP_PKGSet;
import io.ciera.tool.sql.ooaofooa.elementpackaging.impl.EP_PKGSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.ElementVisibilitySet;
import io.ciera.tool.sql.ooaofooa.packageableelement.SearchResultSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.SearchResultSetSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.ElementVisibilitySetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ElementTypeConstants;


public class SearchResultSetSetImpl extends InstanceSet<SearchResultSetSet,SearchResultSet> implements SearchResultSetSet {

    public SearchResultSetSetImpl() {
    }

    public SearchResultSetSetImpl(Comparator<? super SearchResultSet> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setType( ElementTypeConstants m_Type ) throws XtumlException {
        for ( SearchResultSet searchresultset : this ) searchresultset.setType( m_Type );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( SearchResultSet searchresultset : this ) searchresultset.setName( m_Name );
    }
    @Override
    public void setPackage_ID( UniqueId ref_Package_ID ) throws XtumlException {
        for ( SearchResultSet searchresultset : this ) searchresultset.setPackage_ID( ref_Package_ID );
    }


    // selections
    @Override
    public EP_PKGSet R8005_held_by_EP_PKG() throws XtumlException {
        EP_PKGSet ep_pkgset = new EP_PKGSetImpl();
        for ( SearchResultSet searchresultset : this ) ep_pkgset.add( searchresultset.R8005_held_by_EP_PKG() );
        return ep_pkgset;
    }
    @Override
    public ElementVisibilitySet R8006_ElementVisibility() throws XtumlException {
        ElementVisibilitySet elementvisibilityset = new ElementVisibilitySetImpl();
        for ( SearchResultSet searchresultset : this ) elementvisibilityset.addAll( searchresultset.R8006_ElementVisibility() );
        return elementvisibilityset;
    }


    @Override
    public SearchResultSet nullElement() {
        return SearchResultSetImpl.EMPTY_SEARCHRESULTSET;
    }

    @Override
    public SearchResultSetSet emptySet() {
      return new SearchResultSetSetImpl();
    }

    @Override
    public SearchResultSetSet emptySet(Comparator<? super SearchResultSet> comp) {
      return new SearchResultSetSetImpl(comp);
    }

    @Override
    public SearchResultSetSet value() {
        return this;
    }

    @Override
    public List<SearchResultSet> elements() {
        SearchResultSet[] elements = toArray(new SearchResultSet[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
